from __future__ import annotations

from crimes.gcc_diagnostics import GCCDiagnostic


class CError(Exception):
    """
    Base exception class for any error generated by C compilation or runtime.
    """


class CCompileError(CError):
    """
    An error message generated by compiling a C file.
    """

    def __init__(self, error_message: GCCDiagnostic):
        self.first_error = error_message

    def __str__(self):
        return self.first_error.message

    @property
    def line(self) -> int | None:
        if len(self.first_error.locations) > 0:
            return self.first_error.locations[0]["caret"].line
        return None
